@@ -10,7 +10,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -20,7 +20,6 @@
 #define AMAROK_COLLECTION_WIDGET
 
 #include "BrowserCategory.h"
-#include "CollectionTreeItemModelBase.h"
 
 #include <KVBox>
 
@@ -30,6 +29,7 @@ class QStackedWidget;
 
 class SearchWidget;
 class CollectionBrowserTreeView;
+class CollectionTreeItemModelBase;
 
 class CollectionWidget : public BrowserCategory
 {
