@@ -24,6 +24,7 @@
 
 #include <QContextMenuEvent>
 #include <QItemDelegate>
+#include <QMutex>
 #include <QListView>
 #include <QToolButton>
 #include <QWebPage>
@@ -91,7 +92,6 @@ class PodcastView : public Amarok::PrettyTreeView
         ~PodcastView();
 
     protected:
-        void mousePressEvent( QMouseEvent *event );
         void mouseReleaseEvent( QMouseEvent *event );
         void mouseDoubleClickEvent( QMouseEvent *event );
         void startDrag( Qt::DropActions supportedActions );
@@ -103,8 +103,8 @@ class PodcastView : public Amarok::PrettyTreeView
 
         PopupDropper* m_pd;
 
-        QPoint m_dragStartPosition;
-
+        bool m_ongoingDrag;
+        QMutex m_dragMutex;
 };
 
 /**
