@@ -9,7 +9,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -125,7 +125,12 @@ PlaylistBrowserNS::UserModel::loadPlaylists()
     m_playlists.clear();
     while( i.hasNext() )
     {
-        Meta::PlaylistPtr playlist = Meta::PlaylistPtr::staticCast( i.next() );
+        Meta::PlaylistPtr playlist = Meta::PlaylistPtr::dynamicCast( i.next() );
+        if( playlist.isNull() )
+        {
+          error() << "Playlist was NULL!";
+          continue;
+        }
         m_playlists << playlist;
         playlist->subscribe( this );
     }
@@ -159,16 +164,16 @@ PlaylistBrowserNS::UserModel::data(const QModelIndex & index, int role) const
     {
         switch( index.column() )
         {
-            case 0: //playlist
+            case PlaylistColumn: //playlist
                 {
                     food = QVariant::fromValue( playlist );
-                    name = playlist->name();
+                    name = playlist->prettyName();
                     description = playlist->description();
                     icon = KIcon( "amarok_playlist" );
                     groups = playlist->groups();
                 }
                 break;
-            case 1: //group
+            case GroupColumn: //group
                 {
                     if( !playlist->groups().isEmpty() )
                     {
@@ -177,7 +182,7 @@ PlaylistBrowserNS::UserModel::data(const QModelIndex & index, int role) const
                     }
                 }
                 break;
-            case 2: //source
+            case ProviderColumn: //source
                 {
                     PlaylistProvider *provider =
                             The::playlistManager()->getProviderForPlaylist( playlist );
@@ -200,9 +205,7 @@ PlaylistBrowserNS::UserModel::data(const QModelIndex & index, int role) const
         case Qt::EditRole: return name;
         case DescriptionRole:
         case Qt::ToolTipRole: return description;
-        case OriginRole: return QVariant(); //TODO return the provider name
         case Qt::DecorationRole: return QVariant( icon );
-        case GroupRole: return groups;
         default: return QVariant();
     }
 }
@@ -259,17 +262,20 @@ PlaylistBrowserNS::UserModel::rowCount( const QModelIndex & parent ) const
 }
 
 int
-PlaylistBrowserNS::UserModel::columnCount(const QModelIndex & /*parent*/) const
+PlaylistBrowserNS::UserModel::columnCount(const QModelIndex &parent) const
 {
-    //name, group and source
-    return 3;
+    if( !parent.isValid() ) //for playlists (children of root)
+        return 3; //name, group and source
+
+    //for tracks
+    return 1; //only name
 }
 
 Qt::ItemFlags
 PlaylistBrowserNS::UserModel::flags( const QModelIndex & index ) const
 {
     if( !index.isValid() )
-        return Qt::NoItemFlags;
+        return Qt::ItemIsDropEnabled;
 
     if( IS_TRACK(index) )
             return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled;
@@ -284,9 +290,9 @@ PlaylistBrowserNS::UserModel::headerData(int section, Qt::Orientation orientatio
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
         switch( section )
         {
-            case 0: return i18n("Name");
-            case 1: return i18n("Group");
-            case 2: return i18n("Source");
+            case PlaylistColumn: return i18n("Name");
+            case GroupColumn: return i18n("Group");
+            case ProviderColumn: return i18n("Source");
             default: return QVariant();
         }
     }
@@ -295,28 +301,31 @@ PlaylistBrowserNS::UserModel::headerData(int section, Qt::Orientation orientatio
 }
 
 bool
-PlaylistBrowserNS::UserModel::setData(const QModelIndex & index, const QVariant & value, int role)
+PlaylistBrowserNS::UserModel::setData( const QModelIndex &idx, const QVariant &value, int role )
 {
+    Q_UNUSED( role )
     DEBUG_BLOCK
-    switch( role )
+
+    switch( idx.column() )
     {
-        case Qt::EditRole:
+        case PlaylistColumn:
         {
-            debug() << "setting name of item " << index.internalId() << " to " << value.toString();
-            Meta::PlaylistPtr item = m_playlists.value( index.internalId() );
+            debug() << "setting name of item " << idx.internalId() << " to " << value.toString();
+            Meta::PlaylistPtr item = m_playlists.value( idx.internalId() );
             item->setName( value.toString() );
             break;
         }
-        case GroupRole:
+        case GroupColumn:
         {
-            debug() << "changing group of item " << index.internalId() << " to " << value.toString();
-            Meta::PlaylistPtr item = m_playlists.value( index.internalId() );
+            debug() << "changing group of item " << idx.internalId() << " to " << value.toString();
+            Meta::PlaylistPtr item = m_playlists.value( idx.internalId() );
             item->setGroups( value.toStringList() );
             break;
         }
         default:
             return false;
     }
+
     return true;
 }
 
@@ -325,6 +334,28 @@ PlaylistBrowserNS::UserModel::removeRows( int row, int count, const QModelIndex
 {
     DEBUG_BLOCK
     debug() << "in parent " << parent << "remove " << count << " starting at row " << row;
+
+    if( row < 0 || row > rowCount( parent ) )
+        return false;
+
+    if( !parent.isValid() )
+    {
+      Meta::PlaylistList playlistToRemove;
+      for( int i = row; i < row + count; i++ )
+      {
+        if( m_playlists.count() > i )
+        {
+            Meta::PlaylistPtr playlist = m_playlists[i];
+            debug() << "Removing " << playlist->name();
+            playlistToRemove << playlist;
+        }
+      }
+      if( playlistToRemove.isEmpty() )
+        return false;
+
+      The::playlistManager()->deletePlaylists( playlistToRemove );
+      return true;
+    }
     int playlistRow = REMOVE_TRACK_MASK(parent.internalId());
     debug() << "playlist at row: " << playlistRow;
 
@@ -343,7 +374,7 @@ PlaylistBrowserNS::UserModel::removeRows( int row, int count, const QModelIndex
     if( row + count - 1 >= playlist->tracks().count() )
     {
         debug() << "ERROR: tried to remove a track using an index that is not there:";
-        debug() << "row: " << row << " count: " << count << " numbr. of tracks: "
+        debug() << "row: " << row << " count: " << count << " number of tracks: "
                 << playlist->tracks().count();
         return false;
     }
@@ -404,7 +435,7 @@ PlaylistBrowserNS::UserModel::dropMimeData ( const QMimeData *data, Qt::DropActi
         int column, const QModelIndex &parent ) //reimplemented
 {
     DEBUG_BLOCK
-    debug() << "droped on " << QString("row: %1, column: %2, parent:").arg( row ).arg( column );
+    debug() << "dropped on " << QString("row: %1, column: %2, parent:").arg( row ).arg( column );
     debug() << parent;
 
     if( action == Qt::IgnoreAction )
@@ -426,15 +457,25 @@ PlaylistBrowserNS::UserModel::dropMimeData ( const QMimeData *data, Qt::DropActi
         int playlistRow = REMOVE_TRACK_MASK(parent.internalId());
         debug() << "playlist at row: " << playlistRow;
         Meta::PlaylistPtr playlist = m_playlists.value( playlistRow );
-        int insertAt = (row == -1) ? playlist->tracks().count() : row;
-        foreach( Meta::TrackPtr track, dragList->tracks() )
+        if( playlist )
         {
-            debug() << track->prettyName() << "dropped on " << playlist->prettyName() << "insert at " << insertAt;
-            playlist->addTrack( track, insertAt++ );
+            int insertAt = (row == -1) ? playlist->tracks().count() : row;
+            foreach( Meta::TrackPtr track, dragList->tracks() )
+            {
+                debug() << track->prettyName() << "dropped on " << playlist->prettyName() << "insert at " << insertAt;
+                playlist->addTrack( track, insertAt++ );
+            }
+            emit rowsInserted( parent, row, insertAt );
         }
-        emit rowsInserted( parent, row, insertAt );
+        return !playlist.isNull();
+    }
 
-        return true;
+    if( data->hasUrls() )
+    {
+        bool success = true;
+        foreach( const QUrl &url, data->urls() )
+            success = The::playlistManager()->import( url.toString() ) ? success : false;
+        return success;
     }
 
 #if 0
@@ -501,9 +542,16 @@ PlaylistBrowserNS::UserModel::actionsFor( const QModelIndexList &indices )
     {
         foreach( const QModelIndex &idx, indices )
         {
-            actions << The::playlistManager()->trackActions(
+            QList<QAction *> trackActions = The::playlistManager()->trackActions(
                                         m_playlists.value( idx.parent().internalId() ),
-                                        idx.row() );
+                                        idx.row()
+                                    );
+            //only unique actions in the list.
+            foreach( QAction *action, trackActions )
+            {
+                if( !actions.contains( action ) )
+                    actions << action;
+            }
         }
     }
 
@@ -563,6 +611,7 @@ PlaylistBrowserNS::UserModel::createWriteActions( QModelIndexList indices )
 
     if ( m_renameAction == 0 )
     {
+        //FIXME: add ellipsis ("...") since this action opens a dialog
         m_renameAction =  new QAction( KIcon( "media-track-edit-amarok" ), i18n( "&Rename" ), this );
         m_renameAction->setProperty( "pud_svg_id", "edit" );
         connect( m_renameAction, SIGNAL( triggered() ), this, SLOT( slotRename() ) );
