@@ -15,6 +15,7 @@
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
  ****************************************************************************************/
 
+#include "App.h"
 #include "Applet.h"
 #include "Containment.h"
 #include "Debug.h"
@@ -47,6 +48,8 @@ Context::Applet::Applet( QObject * parent, const QVariantList& args )
 {
     connect ( Plasma::Animator::self(), SIGNAL(customAnimationFinished ( int ) ), this, SLOT( animateEnd( int ) ) );
     setBackgroundHints(NoBackground);
+
+    connect( The::paletteHandler(), SIGNAL( newPalette( const QPalette& ) ), SLOT(  paletteChanged( const QPalette &  ) ) );
 }
 
 Context::Applet::~Applet( )
@@ -98,30 +101,34 @@ Context::Applet::truncateTextToFit( QString text, const QFont& font, const QRect
 }
 
 void
-Context::Applet::drawRoundedRectAroundText( QPainter* p, QGraphicsSimpleTextItem* t )
+Context::Applet::drawRoundedRectAroundText( QPainter* p, QGraphicsSimpleTextItem* textItem )
 {
     p->save();
     p->setRenderHint( QPainter::Antialiasing );
 
-    if ( !m_textBackground ) {
+    if ( !m_textBackground )
+    {
         m_textBackground = new Plasma::FrameSvg();
         m_textBackground->setImagePath( "widgets/text-background" );
         m_textBackground->setEnabledBorders( Plasma::FrameSvg::AllBorders );
     }
 
     // Paint in integer coordinates, align to grid
-    QRectF rect = t->boundingRect();
-    QPointF pos = t->pos();
+    QRectF rect = textItem->boundingRect();
     rect.setX( qRound( rect.x() ) );
     rect.setY( qRound( rect.y() ) );
     rect.setHeight( qRound( rect.height() ) );
     rect.setWidth( qRound( rect.width() ) );
-    rect.moveTopLeft( t->pos() );
+    rect.moveTopLeft( textItem->pos() );
+
+    QPointF pos = textItem->pos();
     pos.setX( qRound( pos.x() ) );
     pos.setY( qRound( pos.y() ) );
+
     rect.moveTopLeft( pos );
     rect.adjust( -5, -5, 5, 5 );
-    m_textBackground->resize( rect.size() );
+
+    m_textBackground->resizeFrame( rect.size() );
     m_textBackground->paintFrame( p, rect.topLeft() );
     p->restore();
 }
@@ -346,6 +353,10 @@ Context::Applet::animateEnd( int id )
     emit sizeHintChanged(Qt::PreferredSize);
 }
 
-
+void
+Context::Applet::paletteChanged( const QPalette & palette )
+{
+    Q_UNUSED( palette )
+}
 
 #include "Applet.moc"
