@@ -62,6 +62,9 @@ class AMAROK_EXPORT Applet : public Plasma::Applet
         void setCollapseOff();
         void setCollapseHeight( int );
 
+        bool isAppletCollapsed();
+        bool isAppletExtended();
+
         /**
           * sizeHint is reimplemented here only for all the applet.
           */
@@ -72,13 +75,15 @@ class AMAROK_EXPORT Applet : public Plasma::Applet
           */
         virtual void   resize( qreal, qreal );
 
-
     public Q_SLOTS:
         virtual void destroy();
         void animateOn( qreal );
         void animateOff( qreal );
         void animateEnd( int );
 
+    private slots:
+        void paletteChanged( const QPalette & palette );
+
     protected:
         Plasma::IconWidget* addAction( QAction *action, const int size = 16 );
 
@@ -86,7 +91,8 @@ class AMAROK_EXPORT Applet : public Plasma::Applet
         int  m_heightCurrent;
         int  m_heightCollapseOn;
         int  m_heightCollapseOff;
-        int  m_animationId;
+        int  m_animationIdOn;
+        int  m_animationIdOff;
         int  m_animFromHeight;
 
     private:
