@@ -9,7 +9,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -29,6 +29,8 @@
 #include "Svg.h"
 #include "Theme.h"
 #include "amarokconfig.h"
+#include "amarokurls/AmarokUrlHandler.h"
+#include "amarokurls/ContextUrlRunner.h"
 
 #include <plasma/dataenginemanager.h>
 
@@ -65,7 +67,7 @@ ContextView::ContextView( Plasma::Containment *cont, Plasma::Corona *corona, QWi
    // setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
     setMouseTracking( true );
     setScreen( -1 );
-    
+
     //make background transparent
     QPalette p = palette();
     QColor c = p.color( QPalette::Base );
@@ -79,15 +81,18 @@ ContextView::ContextView( Plasma::Containment *cont, Plasma::Corona *corona, QWi
     Theme::defaultTheme()->setThemeName( "Amarok-Mockup" );
     PERF_LOG( "Access to Plasma::Theme complete" )
     contextScene()->setAppletMimeType( "text/x-amarokappletservicename" );
-  
+
     cont->setPos( 0, 0 );
     cont->updateConstraints();
-    Containment* amarokContainment = qobject_cast<Containment* >( cont );    
+    Containment* amarokContainment = qobject_cast<Containment* >( cont );
     if( amarokContainment )
     {
         amarokContainment->setView( this );
     //    amarokContainment->addCurrentTrack();
     }
+
+    m_urlRunner = new ContextUrlRunner();
+    The::amarokUrlHandler()->registerRunner( m_urlRunner, "context" );
 }
 
 ContextView::~ContextView()
@@ -108,10 +113,12 @@ ContextView::~ContextView()
         while( Plasma::DataEngineManager::self()->engine( engine )->isValid() )
             Plasma::DataEngineManager::self()->unloadEngine( engine );
     }
-     
+
     clear( m_curState );
     //this should be done to prevent a crash on exit
     clearFocus();
+
+    delete m_urlRunner;
 }
 
 
@@ -121,7 +128,7 @@ ContextView::clear( const ContextState& state )
     Q_UNUSED( state )
     DEBUG_BLOCK
 
-    QString name = "amarok_homerc";
+    const QString name = "amarok_homerc";
     // now we save the state, remembering the column info etc
     KConfig appletConfig( name );
     // erase previous config
@@ -140,8 +147,13 @@ ContextView::clear( const ContextState& state )
     contextScene()->clearContainments();
 }
 
+void ContextView::clearNoSave()
+{
+    contextScene()->clearContainments();
+}
 
-void ContextView::enginePlaybackEnded( int finalPosition, int trackLength, EngineObserver::PlaybackEndedReason reason )
+
+void ContextView::enginePlaybackEnded( qint64 finalPosition, qint64 trackLength, EngineObserver::PlaybackEndedReason reason )
 {
     Q_UNUSED( finalPosition )
     Q_UNUSED( trackLength )
@@ -157,7 +169,6 @@ void ContextView::engineNewTrackPlaying()
     DEBUG_BLOCK
     messageNotify( Current );
     m_firstPlayingState = false;
-   
 }
 
 
@@ -168,7 +179,6 @@ ContextView::engineNewMetaData( const QHash<qint64, QString> &newMetaData, bool
     Q_UNUSED( trackChanged )
     DEBUG_BLOCK
 
-
     // if we are listening to a stream, take the new metadata as a "new track"
     Meta::TrackPtr track = The::engineController()->currentTrack();
     if( track && track->type() == "stream" )
@@ -189,7 +199,7 @@ void ContextView::showHome()
 void
 ContextView::loadConfig()
 {
-    contextScene()->clearContainments();    
+    contextScene()->clearContainments();
 
     int numContainments = contextScene()->containments().size();
     KConfig conf( "amarok_homerc", KConfig::FullConfig );
@@ -227,12 +237,10 @@ ContextView::contextScene()
 void
 ContextView::resizeEvent( QResizeEvent* event )
 {
-  //  DEBUG_BLOCK
     Q_UNUSED( event )
-       
-    if ( testAttribute( Qt::WA_PendingResizeEvent ) ) {
+
+    if ( testAttribute( Qt::WA_PendingResizeEvent ) )
         return; // lets not do this more than necessary, shall we?
-    }
 
    updateContainmentsGeometry();
 }
@@ -241,13 +249,8 @@ ContextView::resizeEvent( QResizeEvent* event )
 void
 ContextView::updateContainmentsGeometry()
 {
-  //  DEBUG_BLOCK
-    
-    debug() << "resizing containment to: " << rect();
-
     containment()->resize( rect().size() );
     containment()->setPos( rect().topLeft() );
-
 }
 
 void
@@ -257,6 +260,39 @@ ContextView::wheelEvent( QWheelEvent* event )
         QGraphicsView::wheelEvent( event );
 }
 
+QStringList
+ContextView::currentApplets()
+{
+    DEBUG_BLOCK
+    QStringList appletNames;
+    
+    Applet::List applets = containment()->applets();
+    foreach( Plasma::Applet * applet, applets )
+    {
+        appletNames << applet->pluginName();
+    }
+
+    debug() << "current applets: " << appletNames;
+
+    return appletNames;
+}
+
+QStringList ContextView::currentAppletNames()
+{
+    DEBUG_BLOCK
+    QStringList appletNames;
+
+    Applet::List applets = containment()->applets();
+    foreach( Plasma::Applet * applet, applets )
+    {
+        appletNames << applet->name();
+    }
+
+    debug() << "current applets: " << appletNames;
+
+    return appletNames; 
+}
+
 } // Context namespace
 
 #include "ContextView.moc"
