@@ -9,7 +9,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -58,12 +58,11 @@ public slots:
 private slots:
     void paletteChanged( const QPalette & palette );
     void editLyrics();
+    void closeLyrics();
     void saveLyrics();
 
 private:
-    void calculateHeight();
     void setEditing( const bool isEditing );
-
     void collapseToMin();
 
     QString m_titleText;
@@ -72,7 +71,8 @@ private:
     Plasma::IconWidget*  m_saveIcon;
     Plasma::IconWidget*  m_editIcon;
     Plasma::IconWidget*  m_reloadIcon;
-    
+    Plasma::IconWidget*  m_closeIcon;
+
     // holds main body
     QGraphicsProxyWidget *m_lyricsProxy;
     QTextBrowser* m_lyrics;
