@@ -122,9 +122,12 @@ PhotosApplet::engineNewTrackPlaying( )
 }
 
 void
-PhotosApplet::enginePlaybackEnded( int, int, PlaybackEndedReason )
+PhotosApplet::enginePlaybackEnded( qint64 finalPosition, qint64 trackLength, PlaybackEndedReason )
 {
+    Q_UNUSED( finalPosition )
+    Q_UNUSED( trackLength )
     DEBUG_BLOCK
+
     m_stoppedstate = true;;
     m_headerText->setText( i18n( "Photos" ) + QString( " : " ) + i18n( "No track playing" ) );
     m_widget->clear();
@@ -197,6 +200,7 @@ PhotosApplet::dataUpdated( const QString& name, const Plasma::DataEngine::Data&
     // if we get a message, show it
     if ( data.contains( "message" ) && data["message"].toString().contains("Fetching"))
     {
+        //FIXME: This should use i18n( "blah %1 blah", foo ). 
         m_headerText->setText( i18n( "Photos" ) + QString( " : " ) + i18n( "Fetching ..." ) );
         updateConstraints();
         update();
@@ -205,8 +209,18 @@ PhotosApplet::dataUpdated( const QString& name, const Plasma::DataEngine::Data&
         m_widget->hide();
         setBusy( true );
     }
+    else if ( data.contains( "message" ) && data["message"].toString().contains("NA_Collapse") )
+    {
+        updateConstraints();
+        update();
+        setCollapseOn();
+        m_widget->clear();
+        m_widget->hide();
+        setBusy( false );
+    }
     else if ( data.contains( "message" ) )
     {
+        //FIXME: This should use i18n( "blah %1 blah", foo ). 
         m_headerText->setText( i18n( "Photos" ) + " : " + data[ "message" ].toString() );
         updateConstraints();
         update();
@@ -221,6 +235,7 @@ PhotosApplet::dataUpdated( const QString& name, const Plasma::DataEngine::Data&
         // this also prevent the stupid effect of reanimating several time.
         if ( isAppletExtended() )
         {
+            //FIXME: This should use i18n( "blah %1 blah", foo ). 
             m_headerText->setText( i18n( "Photos" ) + QString( " : " ) + data[ "artist" ].toString() );
             updateConstraints();
             update();
