@@ -120,6 +120,9 @@ private:
     /// The fetch failed, finish up and log an error message
     void finishWithError( const QString &message, KJob *job = 0 );
 
+    /// The fetch was successful, but there was no cover found
+    void finishNotFound();
+
     /// Show the cover that has been found
     void showCover();
 };
