@@ -8,7 +8,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Public License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -137,11 +137,7 @@ FastForwardWorker::run()
         "ORDER BY lastmountpoint, S.url" );
     QSqlQuery query( sql, db );
 
-    const bool queried = query.exec();
-
-    debug() << "exec()" << queried << "active?" << query.isActive() << "size:" << query.size();
-
-    if( !queried || query.lastError().isValid() )
+    if( query.lastError().isValid() )
     {
         QString errorMsg = i18n( "Could not execute import query: %1", db.lastError().text() );
         error() << "Error executing import query:" << errorMsg;
@@ -150,6 +146,8 @@ FastForwardWorker::run()
         return;
     }
 
+    debug() << "active?" << query.isActive() << "size:" << query.size();
+
     QMap<Meta::TrackPtr,QString> tracksForInsert;
 
     for( int c = 0; query.next(); c++ )
@@ -191,8 +189,11 @@ FastForwardWorker::run()
                 tracksForInsert.insert( track, track->playableUrl().url() );
                 debug() << c << " inserting track:" << track->playableUrl();
             }
-            else
-                debug() << c << " track in collection (" << track->collection()->location()->prettyLocation() << "):" << track->playableUrl();
+            else {
+                Amarok::Collection* collection = track->collection();
+                if (collection)
+                    debug() << c << " track in collection (" << track->collection()->location()->prettyLocation() << "):" << track->playableUrl();
+            }
 
             emit trackAdded( track );
 
