@@ -28,6 +28,7 @@
 #include <kio/global.h>
 
 // Taglib
+#include <fileref.h>
 #include <tag.h>
 #include <tlist.h>
 #include <tmap.h>
@@ -124,6 +125,54 @@ Meta::Field::mapFromTrack( const Meta::TrackPtr track )
     return map;
 }
 
+QVariantMap
+Meta::Field::mprisMapFromTrack( const Meta::TrackPtr track )
+{
+    QVariantMap map;
+    if( track )
+    {
+        // MANDATORY:
+        map["location"] = track->playableUrl().url();
+        // INFORMATIONAL:
+        map["title"] = track->prettyName();
+
+        if( track->artist() )
+            map["artist"] = track->artist()->name();
+
+        if( track->album() )
+            map["album"] = track->album()->name();
+
+        map["tracknumber"] = track->trackNumber();
+        map["time"] = track->length() / 1000;
+        map["mtime"] = track->length();
+
+        if( track->genre() )
+            map["genre"] = track->genre()->name();
+
+        map["comment"] = track->comment();
+        map["rating"] = track->rating()/2;  //out of 5, not 10.
+
+        if( track->year() )
+            map["year"] = track->year()->name();
+
+        if( track->album() )
+            map["arturl"] = track->album()->imageLocation().url();
+
+        //TODO: external service meta info
+
+        // TECHNICAL:
+        map["audio-bitrate"] = track->bitrate();
+        map["audio-samplerate"] = track->sampleRate();
+        //amarok has no video-bitrate
+
+        // EXTRA Amarok specific
+        const QString lyrics = track->cachedLyrics();
+        if( !lyrics.isEmpty() )
+            map["lyrics"] = lyrics;
+    }
+    return map;
+}
+
 
 void
 Meta::Field::updateTrack( Meta::TrackPtr track, const QVariantMap &metadata )
@@ -185,7 +234,7 @@ Meta::Field::writeFields( TagLib::FileRef fileref, const QVariantMap &changes )
 {
     if( fileref.isNull() || changes.isEmpty() )
         return;
-    
+
     TagLib::Tag *tag = fileref.tag();
     if( !tag )
         return;
@@ -445,7 +494,7 @@ Meta::Field::xesamFullToPrettyFieldName( const QString &name )
 
 
 QString
-Meta::msToPrettyTime( int ms )
+Meta::msToPrettyTime( qint64 ms )
 {
     return Meta::secToPrettyTime( ms / 1000 );
 }
@@ -476,7 +525,7 @@ Meta::secToPrettyTime( int seconds )
 }
 
 QString
-Meta::prettyFilesize( int size )
+Meta::prettyFilesize( quint64 size )
 {
     return KIO::convertSize( size );
 }
@@ -515,3 +564,17 @@ Meta::prettyRating( int rating )
     }
     return "if you can see this, then that's a bad sign.";
 }
+
+TrackKey
+Meta::keyFromTrack( const Meta::TrackPtr &track )
+{
+    TrackKey k;
+    k.trackName = track->name();
+    if( track->artist() )
+        k.artistName = track->artist()->name();
+
+    if( track->album() )
+        k.albumName = track->album()->name();
+
+    return k;
+}
