@@ -122,6 +122,12 @@ protected slots:
      */
     void slotRemovedIds( const QList<quint64> &ids );
 
+    /**
+     * Slot that wraps around the method invalidateFilter() so one doesn't trigger the
+     * sorting invalidation too by using invalidate().
+     */
+    void slotInvalidateFilter(){ invalidateFilter(); }
+
 signals:
     /**
      * Signal forwarded from the source model.
@@ -129,6 +135,12 @@ signals:
      */
     void insertedIds( const QList<quint64>& );
 
+    /**
+     * Signal forwarded from the source model.
+     * Emitted before items are removed from the model.
+     */
+    void beginRemoveIds();
+
     /**
      * Signal forwarded from the source model.
      * @param the list of id's removed that are also represented by this proxy.
