@@ -69,6 +69,14 @@ public:
      */
     virtual Meta::TrackPtr activeTrack() const;
 
+    /**
+     * Returns all rows in the current model which match a given track pointer.
+     * @see firstRowForTrack
+     * @param track the track.
+     * @return collection of rows, empty if the track pointer is invalid.
+     */
+    virtual QSet<int> allRowsForTrack( const Meta::TrackPtr track ) const;
+
     /**
      * Clears the current search term.
      */
@@ -179,6 +187,14 @@ public:
      */
     virtual int findPrevious( const QString &searchTerm, int selectedRow, int searchFields );
 
+    /**
+     * Returns the first row in the current model which matches a given track pointer.
+     * @see allRowsForTrack
+     * @param track the track.
+     * @return the row, -1 if the track pointer is invalid.
+     */
+    virtual int firstRowForTrack( const Meta::TrackPtr track ) const;
+
     /**
      * Returns the item flags for the given index.
      * @param index the index to retrieve the flags for.
@@ -229,13 +245,6 @@ public:
      */
     virtual int rowForId( const quint64 id ) const;
 
-    /**
-     * Returns the row in the current model for a given track pointer.
-     * @param track the track.
-     * @return the row, -1 if the track pointer is invalid.
-     */
-    virtual int rowForTrack( const Meta::TrackPtr track ) const;
-
     /**
      * Returns the row number of a track in terms of the bottom model.
      * @param row the row in a proxy model
@@ -304,9 +313,17 @@ public:
      * Returns the total length of the playlist.
      * The default implementation forwards the total time from the proxy or model below the
      * current proxy.
-     * @return the total length of the playlist.
+     * @return the total length of the playlist in milliseconds.
      */
-    virtual int totalLength() const;
+    virtual qint64 totalLength() const;
+
+    /**
+     * Returns the total size of the playlist.
+     * The default implementation forwards the total size from the proxy or model below the
+     * current proxy.
+     * @return the total size of the playlist.
+     */
+    virtual quint64 totalSize() const;
 
     /**
      * Returns a pointer to the track at a given row in the current proxy.
@@ -336,6 +353,12 @@ signals:
      */
     void insertedIds( const QList<quint64>& );
 
+    /**
+     * Signal forwarded from the source model.
+     * Emitted before items are removed from the model.
+     */
+    void beginRemoveIds();
+
     /**
      * Signal forwarded from the source model. IDs are unique so they shouldn't be modified
      * by the proxies.
