@@ -63,7 +63,7 @@ public slots:
     /**
      * Resets the proxy to its original pass-through state.
      */
-    void invalidateSorting();
+    void resetSorting();
 
 protected:
     /**
@@ -82,6 +82,12 @@ protected:
      */
     virtual int rowToSource( int row ) const;
 
+protected slots:
+    /**
+     * Reapplies the current sorting scheme.
+     */
+    void invalidateSorting();
+
 private:
     SortScheme m_scheme;               //! The current sorting scheme.
 };
