@@ -43,13 +43,6 @@
 
 using namespace Playlist;
 
-const qreal PrettyItemDelegate::ALBUM_WIDTH = 50.0;
-const qreal PrettyItemDelegate::SINGLE_TRACK_ALBUM_WIDTH = 40.0;
-const qreal PrettyItemDelegate::MARGIN = 2.0;
-const qreal PrettyItemDelegate::MARGINH = 6.0;
-const qreal PrettyItemDelegate::MARGINBODY = 1.0;
-const qreal PrettyItemDelegate::PADDING = 1.0;
-
 int Playlist::PrettyItemDelegate::s_fontHeight = 0;
 
 
@@ -124,7 +117,7 @@ void
 PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index ) const
 {
     PlaylistLayout layout = LayoutManager::instance()->activeLayout();
-    
+
     painter->save();
     QApplication::style()->drawPrimitive( QStyle::PE_PanelItemViewItem, &option, painter );
     painter->translate( option.rect.topLeft() );
@@ -151,7 +144,7 @@ PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option
         if ( paintInlineControls )
         {
             int adjustedRowCount = rowCount + 1;
-            trackHeight = ( option.rect.height() * rowCount ) / adjustedRowCount;
+            trackHeight = ( option.rect.height() * rowCount ) / adjustedRowCount + 3;
             extraHeight = option.rect.height() - trackHeight;
             trackOption.rect = QRect( 0, 0, option.rect.width(), trackHeight );
         }
@@ -162,7 +155,7 @@ PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option
             paintItem( layout.body(), painter, trackOption, index );
         else
             paintItem( layout.body(), painter, trackOption, index );
-        
+
         if (paintInlineControls )
         {
             QRect extrasRect( 0, trackHeight, option.rect.width(), extraHeight );
@@ -194,15 +187,15 @@ PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option
             totalRows = totalRows + 1;
         }
 
-        int headHeight = ( headRows * option.rect.height() ) / totalRows - 1;
-        int trackHeight = ( trackRows * option.rect.height() ) / totalRows;
+        int headHeight = ( headRows * option.rect.height() ) / totalRows - 2;
+        int trackHeight = ( trackRows * option.rect.height() ) / totalRows + 3;
 
         if ( headRows > 0 )
         {
             headOption.rect = QRect( 0, 0, option.rect.width(), headHeight );
             paintItem( layout.head(), painter, headOption, index, true );
             painter->translate( 0, headHeight );
-        } 
+        }
 
         trackOption.rect = QRect( 0, 0, option.rect.width(), trackHeight );
         paintItem( layout.body(), painter, trackOption, index );
@@ -214,7 +207,7 @@ PrettyItemDelegate::paint( QPainter* painter, const QStyleOptionViewItem& option
             paintActiveTrackExtras( extrasRect, painter, index );
 
         }
-    } 
+    }
     else
         QStyledItemDelegate::paint( painter, option, index );
 
@@ -233,7 +226,7 @@ PrettyItemDelegate::insideItemHeader( const QPoint& pt, const QRect& rect )
                                         ( int )MARGIN,
                                         ( int )( -MARGINH ),
                                                     0 );
-    
+
     headerBounds.setHeight( static_cast<int>( 2 * MARGIN + headRows * s_fontHeight ) );
 
     return headerBounds.contains( pt );
@@ -262,7 +255,7 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
 
     if ( rowCount == 0 )
         return;
-    
+
     int rowHeight = option.rect.height() / rowCount;
 
     int rowOffsetX = MARGINH;
@@ -270,82 +263,13 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
 
     int imageSize = option.rect.height() - MARGIN * 2;
     QRectF nominalImageRect( MARGINH, MARGIN, imageSize, imageSize );
-    
-    if ( config.showCover() )
-    {
-        QModelIndex coverIndex = index.model()->index( index.row(), CoverImage );
-        QPixmap albumPixmap = coverIndex.data( Qt::DisplayRole ).value<QPixmap>();
-
-        //offset cover if non square
-        QPointF offset = centerImage( albumPixmap, nominalImageRect );
-        QRectF imageRect( nominalImageRect.x() + offset.x(),
-                          nominalImageRect.y() + offset.y(),
-                          nominalImageRect.width() - offset.x() * 2,
-                          nominalImageRect.height() - offset.y() * 2 );
-
-        if ( !albumPixmap.isNull() )
-            painter->drawPixmap( imageRect, albumPixmap, QRectF( albumPixmap.rect() ) );
-
-        QModelIndex emblemIndex = index.model()->index( index.row(), SourceEmblem );
-        QPixmap emblemPixmap = emblemIndex.data( Qt::DisplayRole ).value<QPixmap>();
-
-        if ( !albumPixmap.isNull() )
-            painter->drawPixmap( QRectF( nominalImageRect.x(), nominalImageRect.y() , 16, 16 ), emblemPixmap, QRectF( 0, 0 , 16, 16 ) );
-
-        rowOffsetX = imageSize + MARGINH + PADDING * 2;
-    }
 
     int markerOffsetX = nominalImageRect.x();
-    
-    if( index.data( StateRole ).toInt() & Item::Queued && !ignoreQueueMarker )
-    {
-        // Check that the queue position is actually valid
-        const int queuePosition = index.data( QueuePositionRole ).toInt();
-        if( queuePosition > 0 )
-        {
-            const int w = 16, h = 16;
-            const int x = markerOffsetX;
-            const int y = nominalImageRect.y() + ( imageSize - h );
-            const QRect rect( x, y, w, h );
-            painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "queue_marker", w, h, "queue_marker" ) );
-            painter->drawText( rect, Qt::AlignCenter, QString::number( queuePosition ) );
 
-            markerOffsetX += ( 16 + PADDING );
+    const bool showCover = config.showCover();
 
-            if ( !config.showCover() )
-                rowOffsetX = markerOffsetX;
-        }
-        else
-            warning() << "discrepancy: Item::Queued but queuePosition == 0";
-    }
-
-    if( index.data( MultiSourceRole ).toBool() && !ignoreQueueMarker )
-    {
-        const int w = 16, h = 16;
-        const int x = markerOffsetX;
-        const int y = nominalImageRect.y() + ( imageSize - h );
-        const QRect rect( x, y, w, h );
-        painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "multi_marker", w, h, "multi_marker" ) );
-
-        markerOffsetX += ( 16 + PADDING );
-
-        if ( !config.showCover() )
-            rowOffsetX += ( 16 + PADDING );
-    }
-
-    if( index.data( StopAfterTrackRole ).toBool() )
-    {
-        const int w = 16, h = 16;
-        const int x = markerOffsetX;
-        const int y = nominalImageRect.y() + ( imageSize - h );
-        const QRect rect( x, y, w, h );
-        painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "stop_button", w, h, "stop_button" ) );
-
-        markerOffsetX += ( 16 + PADDING );
-
-        if ( !config.showCover() )
-            rowOffsetX += ( 16 + PADDING );
-    }
+    if ( showCover )
+        rowOffsetX = imageSize + MARGINH + PADDING * 2;
 
     for ( int i = 0; i < rowCount; i++ )
     {
@@ -363,24 +287,25 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
             //TODO: propper 9 part painting, but I dont want to bother with this until we
             //get some new graphics anyway...
 
-            int overlayXOffset = rowOffsetX - 3;
-            int overlayHeight = rowHeight - 2;
-            int overlayLength = rowWidth + 6;
+            int overlayXOffset = 0;
+            int overlayYOffset = rowOffsetY - 1;
+            int overlayHeight = option.rect.height() + 1;
+            int overlayLength = option.rect.width();
             int endWidth = overlayHeight / 4;
 
-            painter->drawPixmap( overlayXOffset, rowOffsetY + 1,
+            painter->drawPixmap( overlayXOffset, overlayYOffset,
                                  The::svgHandler()->renderSvg(
                                  "active_overlay_left",
                                  endWidth, overlayHeight,
                                  "active_overlay_left" ) );
-           
-            painter->drawPixmap( overlayXOffset + endWidth, rowOffsetY + 1,
+
+            painter->drawPixmap( overlayXOffset + endWidth, overlayYOffset,
                                  The::svgHandler()->renderSvg(
                                  "active_overlay_mid",
                                  overlayLength - endWidth * 2, overlayHeight,
                                  "active_overlay_mid" ) );
 
-            painter->drawPixmap( overlayXOffset + ( overlayLength - endWidth ), rowOffsetY + 1,
+            painter->drawPixmap( overlayXOffset + ( overlayLength - endWidth ), overlayYOffset,
                                  The::svgHandler()->renderSvg(
                                  "active_overlay_right",
                                  endWidth, overlayHeight,
@@ -389,7 +314,7 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
 
         QRectF rowBox( itemOffsetX, rowOffsetY, rowWidth, rowHeight );
         int currentItemX = itemOffsetX;
-        
+
         //we need to do a quick pass to figure out how much space is left for auto sizing elements
         qreal spareSpace = 1.0;
         int autoSizeElemCount = 0;
@@ -417,11 +342,13 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
 
             bool bold = element.bold();
             bool italic = element.italic();
+            bool underline = element.underline();
             int alignment = element.alignment();
 
             QFont font = option.font;
             font.setBold( bold );
             font.setItalic( italic );
+            font.setUnderline( underline );
             painter->setFont( font );
 
             QRectF elementBox;
@@ -429,7 +356,7 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
             qreal size;
             if ( element.size() > 0.0001 )
                 size = element.size();
-            else 
+            else
                 size = spacePerAutoSizeElem;
 
             if ( size > 0.0001 )
@@ -493,12 +420,83 @@ void Playlist::PrettyItemDelegate::paintItem( LayoutItemConfig config, QPainter*
         rowOffsetY += rowHeight;
     }
 
+    if ( showCover )
+    {
+        QModelIndex coverIndex = index.model()->index( index.row(), CoverImage );
+        QPixmap albumPixmap = coverIndex.data( Qt::DisplayRole ).value<QPixmap>();
+
+        //offset cover if non square
+        QPointF offset = centerImage( albumPixmap, nominalImageRect );
+        QRectF imageRect( nominalImageRect.x() + offset.x(),
+                          nominalImageRect.y() + offset.y(),
+                          nominalImageRect.width() - offset.x() * 2,
+                          nominalImageRect.height() - offset.y() * 2 );
+
+        if ( !albumPixmap.isNull() )
+            painter->drawPixmap( imageRect, albumPixmap, QRectF( albumPixmap.rect() ) );
+
+        QModelIndex emblemIndex = index.model()->index( index.row(), SourceEmblem );
+        QPixmap emblemPixmap = emblemIndex.data( Qt::DisplayRole ).value<QPixmap>();
+
+        if ( !albumPixmap.isNull() )
+            painter->drawPixmap( QRectF( nominalImageRect.x(), nominalImageRect.y() , 16, 16 ), emblemPixmap, QRectF( 0, 0 , 16, 16 ) );
+    }
+
+    if( index.data( StateRole ).toInt() & Item::Queued && !ignoreQueueMarker )
+    {
+        // Check that the queue position is actually valid
+        const int queuePosition = index.data( QueuePositionRole ).toInt();
+        if( queuePosition > 0 )
+        {
+            const int w = 16, h = 16;
+            const int x = markerOffsetX;
+            const int y = nominalImageRect.y() + ( imageSize - h );
+            const QRect rect( x, y, w, h );
+            painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "queue_marker", w, h, "queue_marker" ) );
+            painter->drawText( rect, Qt::AlignCenter, QString::number( queuePosition ) );
+
+            markerOffsetX += ( 16 + PADDING );
+
+            if ( !showCover )
+                rowOffsetX = markerOffsetX;
+        }
+        else
+            warning() << "discrepancy: Item::Queued but queuePosition == 0";
+    }
+
+    if( index.data( MultiSourceRole ).toBool() && !ignoreQueueMarker )
+    {
+        const int w = 16, h = 16;
+        const int x = markerOffsetX;
+        const int y = nominalImageRect.y() + ( imageSize - h );
+        const QRect rect( x, y, w, h );
+        painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "multi_marker", w, h, "multi_marker" ) );
+
+        markerOffsetX += ( 16 + PADDING );
+
+        if ( !showCover )
+            rowOffsetX += ( 16 + PADDING );
+    }
+
+    if( index.data( StopAfterTrackRole ).toBool() )
+    {
+        const int w = 16, h = 16;
+        const int x = markerOffsetX;
+        const int y = nominalImageRect.y() + ( imageSize - h );
+        const QRect rect( x, y, w, h );
+        painter->drawPixmap( x, y, The::svgHandler()->renderSvg( "stop_button", w, h, "stop_button" ) );
+
+        markerOffsetX += ( 16 + PADDING );
+
+        if ( !showCover )
+            rowOffsetX += ( 16 + PADDING );
+    }
 }
 
 void Playlist::PrettyItemDelegate::paintActiveTrackExtras( const QRect &rect, QPainter* painter, const QModelIndex& index ) const
 {
     Q_UNUSED( index );
-    
+
     int x = rect.x();
     int y = rect.y();
     int width = rect.width();
@@ -527,7 +525,7 @@ void Playlist::PrettyItemDelegate::paintActiveTrackExtras( const QRect &rect, QP
     }
     else
     {
-                              
+
     offset += ( buttonSize + MARGINH );
     painter->drawPixmap( offset, y + 2,
                             The::svgHandler()->renderSvg(
@@ -542,8 +540,8 @@ void Playlist::PrettyItemDelegate::paintActiveTrackExtras( const QRect &rect, QP
                          "stop_button",
                          buttonSize, buttonSize,
                          "stop_button" ) );
-                         
-    offset += ( buttonSize + MARGINH );                        
+
+    offset += ( buttonSize + MARGINH );
     painter->drawPixmap( offset, y + 2,
                          The::svgHandler()->renderSvg(
                          "next_button",
@@ -552,7 +550,7 @@ void Playlist::PrettyItemDelegate::paintActiveTrackExtras( const QRect &rect, QP
 
     offset += ( buttonSize + MARGINH );
 
-    long trackLength = EngineController::instance()->trackLength() * 1000;
+    long trackLength = EngineController::instance()->trackLength();
     long trackPos = EngineController::instance()->trackPositionMs();
     qreal trackPercentage = 0.0;
 
@@ -561,26 +559,26 @@ void Playlist::PrettyItemDelegate::paintActiveTrackExtras( const QRect &rect, QP
 
     int sliderWidth = width - ( offset + MARGINH );
 
-    The::svgHandler()->paintCustomSlider( painter, offset, y, sliderWidth, height, trackPercentage, false );  
+    The::svgHandler()->paintCustomSlider( painter, offset, y, sliderWidth, height, trackPercentage, false );
 }
 
 bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &itemRect, const QModelIndex& index )
 {
-    
+
     //for now, only handle clicks in the currently playing item.
     if ( !index.data( ActiveTrackRole ).toBool() )
         return false;
 
-    //also, if we are not using the inline controls, we should not reacto to these clicks at all
+    //also, if we are not using the inline controls, we should not react to these clicks at all
     if( !LayoutManager::instance()->activeLayout().inlineControls() )
         return false;
-    
+
     int rowCount = rowsForItem( index );
     int modifiedRowCount = rowCount + 1;
 
     int height = itemRect.height();;
 
-    int baseHeight = ( height * rowCount ) / modifiedRowCount;
+    int baseHeight = ( height * rowCount ) / modifiedRowCount + 3;
     int extrasHeight = height - baseHeight;
     int extrasOffsetY = height - extrasHeight;
 
@@ -594,7 +592,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
          return true;
     }
 
-    offset += ( buttonSize + MARGINH ); 
+    offset += ( buttonSize + MARGINH );
     QRect playRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( playRect.contains( pos ) )
     {
@@ -602,7 +600,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
          return true;
     }
 
-    offset += ( buttonSize + MARGINH ); 
+    offset += ( buttonSize + MARGINH );
     QRect stopRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( stopRect.contains( pos ) )
     {
@@ -611,33 +609,33 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
     }
 
 
-    offset += ( buttonSize + MARGINH ); 
+    offset += ( buttonSize + MARGINH );
     QRect nextRect( offset, extrasOffsetY + 2, buttonSize, buttonSize );
     if( nextRect.contains( pos ) )
     {
          Amarok::actionCollection()->action( "next" )->trigger();
          return true;
     }
-    
+
     offset += ( buttonSize + MARGINH );
 
     //handle clicks on the slider
 
     int sliderWidth = itemRect.width() - ( offset + MARGINH );
     int knobSize = buttonSize - 2;
-    
+
     QRect sliderActiveRect( offset, extrasOffsetY + 3, sliderWidth, knobSize );
     if( sliderActiveRect.contains( pos ) )
     {
         int xSliderPos = pos.x() - offset;
-        long trackLength = EngineController::instance()->trackLength() * 1000;
+        long trackLength = EngineController::instance()->trackLength();
 
         qreal percentage = (qreal) xSliderPos / (qreal) sliderWidth;
         EngineController::instance()->seek( trackLength * percentage );
         return true;
 
     }
-    
+
 
     return false;
 }
@@ -645,7 +643,7 @@ bool Playlist::PrettyItemDelegate::clicked( const QPoint &pos, const QRect &item
 QWidget * Playlist::PrettyItemDelegate::createEditor ( QWidget * parent, const QStyleOptionViewItem & option, const QModelIndex & index ) const
 {
     Q_UNUSED( option );
-    
+
     DEBUG_BLOCK
     const int groupMode = getGroupMode(index);
     return new InlineEditorWidget( parent, index, LayoutManager::instance()->activeLayout(), groupMode );
@@ -661,7 +659,7 @@ void Playlist::PrettyItemDelegate::setModelData( QWidget * editor, QAbstractItem
         return;
 
     QMap<int, QString> changeMap = inlineEditor->changedValues();
-    
+
     debug() << "got inline editor!!";
     debug() << "changed values map: " << changeMap;
 
@@ -681,7 +679,7 @@ void Playlist::PrettyItemDelegate::setModelData( QWidget * editor, QAbstractItem
     foreach( int column, columns )
     {
         QString value = changeMap.value( column );
-        
+
         switch( column )
         {
             case Album:
