@@ -20,6 +20,7 @@
 #include "Amarok.h"
 #include "CollectionManager.h"
 #include "Debug.h"
+#include "MainWindow.h"
 #include "meta/M3UPlaylist.h"
 #include "meta/PLSPlaylist.h"
 #include "meta/XSPFPlaylist.h"
@@ -28,11 +29,13 @@
 #include "SvgHandler.h"
 #include "UserPlaylistModel.h"
 
+#include <KDialog>
 #include <KIcon>
 #include <KInputDialog>
 #include <KUrl>
 
 #include <QAction>
+#include <QLabel>
 #include <QMap>
 
 static const int USERPLAYLIST_DB_VERSION = 2;
@@ -71,19 +74,7 @@ void
 SqlUserPlaylistProvider::slotDelete()
 {
     DEBUG_BLOCK
-
-    //TODO FIXME Confirmation of delete
-    foreach( Meta::PlaylistPtr playlist, The::userPlaylistModel()->selectedPlaylists() )
-    {
-        Meta::SqlPlaylistPtr sqlPlaylist =
-                Meta::SqlPlaylistPtr::dynamicCast( playlist );
-        if( sqlPlaylist )
-        {
-            debug() << "deleting " << sqlPlaylist->name();
-            sqlPlaylist->removeFromDb();
-        }
-    }
-    reloadFromDb();
+    deletePlaylists( The::userPlaylistModel()->selectedPlaylists() );
 }
 
 void
@@ -111,7 +102,7 @@ SqlUserPlaylistProvider::slotRemove()
         return;
 
     PlaylistTrackMap playlistMap = action->data().value<PlaylistTrackMap>();
-    foreach( Meta::PlaylistPtr playlist, playlistMap.keys() )
+    foreach( Meta::PlaylistPtr playlist, playlistMap.uniqueKeys() )
         foreach( Meta::TrackPtr track, playlistMap.values( playlist ) )
             playlist->removeTrack( playlist->tracks().indexOf( track ) );
 
@@ -165,9 +156,16 @@ SqlUserPlaylistProvider::trackActions( Meta::PlaylistPtr playlist, int trackInde
         connect( m_removeTrackAction, SIGNAL( triggered() ), SLOT( slotRemove() ) );
     }
     //Add the playlist/track combination to a QMultiMap that is stored in the action.
-    //In the slot we use this data and use it to remove that track.
+    //In the slot we use this data to remove that track from the playlist.
     PlaylistTrackMap playlistMap = m_removeTrackAction->data().value<PlaylistTrackMap>();
-    playlistMap.insert( playlist, playlist->tracks()[trackIndex] );
+    Meta::TrackPtr track = playlist->tracks()[trackIndex];
+    //only add action to map if playlist/track combo is not in there yet.
+    if( !playlistMap.keys().contains( playlist ) ||
+           !playlistMap.values( playlist ).contains( track )
+      )
+    {
+        playlistMap.insert( playlist, track );
+    }
     m_removeTrackAction->setData( QVariant::fromValue( playlistMap ) );
 
     actions << m_removeTrackAction;
@@ -175,6 +173,34 @@ SqlUserPlaylistProvider::trackActions( Meta::PlaylistPtr playlist, int trackInde
     return actions;
 }
 
+void
+SqlUserPlaylistProvider::deletePlaylists( Meta::PlaylistList playlistList )
+{
+    KDialog dialog( The::mainWindow() );
+    dialog.setCaption( i18n( "Confirm Delete" ) );
+    dialog.setButtons( KDialog::Ok | KDialog::Cancel );
+    QLabel label( i18np( "Are you sure you want to delete this playlist?",
+                         "Are you sure you want to delete these %1 playlists?",
+                         playlistList.count() )
+                    , &dialog
+                  );
+    dialog.setButtonText( KDialog::Ok, i18n( "Yes, delete from database." ) );
+    dialog.setMainWidget( &label );
+    if( dialog.exec() != QDialog::Accepted )
+        return;
+    foreach( Meta::PlaylistPtr playlist, playlistList )
+    {
+        Meta::SqlPlaylistPtr sqlPlaylist =
+                Meta::SqlPlaylistPtr::dynamicCast( playlist );
+        if( sqlPlaylist )
+        {
+            debug() << "deleting " << sqlPlaylist->name();
+            sqlPlaylist->removeFromDb();
+        }
+    }
+    reloadFromDb();
+}
+
 Meta::PlaylistPtr
 SqlUserPlaylistProvider::save( const Meta::TrackList &tracks )
 {
@@ -351,7 +377,12 @@ SqlUserPlaylistProvider::checkTables()
     DEBUG_BLOCK
 
     SqlStorage *sqlStorage = CollectionManager::instance()->sqlStorage();
-    QStringList values = sqlStorage->query( QString("SELECT version FROM admin WHERE component = '%1';").arg(sqlStorage->escape( key ) ) );
+    QStringList values;
+
+    //Prevents amarok from crashing on bad DB
+    if ( sqlStorage )
+            values = sqlStorage->query( QString("SELECT version FROM admin WHERE component = '%1';").arg(sqlStorage->escape( key ) ) );
+    
     if( values.isEmpty() )
     {
         //debug() << "creating Playlist Tables";
