@@ -272,7 +272,7 @@ Track::discNumber() const
     return 0;
 }
 
-int
+qint64
 Track::length() const
 {
     return d->length;
@@ -364,7 +364,8 @@ Track::collection() const
 void
 Track::setTrackInfo( const lastfm::Track &track )
 {
-    d->setTrackInfo( track );
+    if( !track.isNull() )
+        d->setTrackInfo( track );
 }
 
 QString
@@ -568,7 +569,7 @@ QPixmap LastFm::Track::emblem()
     else
         return QPixmap();
 }
- 
+
 QString LastFm::Track::scalableEmblem()
 {
     if ( !d->track.isEmpty() )
