@@ -66,8 +66,8 @@ namespace Amarok
             /// we flip the value for vertical sliders
             int adjustValue( int v ) const
             {
-               int mp = (minimum() + maximum()) / 2;
-               return orientation() == Qt::Vertical ? mp - (v - mp) : v;
+               int mp = ( minimum() + maximum() ) / 2;
+               return orientation() == Qt::Vertical ? mp - ( v - mp ) : v;
             }
 
             static const int m_borderWidth = 6;
@@ -125,11 +125,13 @@ namespace Amarok
 
         public slots:
             void slotTriangleClicked( int );
+            void slotTriangleFocused( int );
 
         protected:
             virtual void paintEvent( QPaintEvent* );
             virtual void mousePressEvent( QMouseEvent* );
-            virtual void resizeEvent(QResizeEvent * event);
+            virtual void resizeEvent( QResizeEvent * event );
+            virtual void sliderChange( SliderChange change );
             virtual bool event ( QEvent * event );
 
         private:
@@ -137,7 +139,7 @@ namespace Amarok
 
             QTimer *m_animTimer; // Used for a smooth progress.
             QList<BookmarkTriangle*> m_triangles;
-            double m_knobX; // The position of the current indicator.
+            int m_knobX; // The position of the current indicator.
     };
 }
 
